@@ -88,7 +88,9 @@ class MovieSeries(KinopoiskPage):
             if '21px' not in season['style']:
                 continue
 
-            year = self.prepare_int(season.nextSibling.string[:4])
+
+
+            year = self.prepare_int(season.nextSibling.split(',')[0])
             tbody = season.parent.parent.parent
             episodes = []
             for tr in tbody.findAll('tr')[1:]:
@@ -176,4 +178,5 @@ class MovieTrailersPage(KinopoiskPage):
         for trailer in trailers:
             instance.add_trailer(json.loads(trailer.replace("'",'"')))
 
-        instance.set_source(self.content_name)
+        instance.youtube_ids = list(set(re.findall(r'http://www.youtube.com/v/(.+)\?', content)))
+        instance.set_source(self.content_name)
\ No newline at end of file
